@@ -8,6 +8,7 @@ def pip_install():
     os.system('pip install requests')
     os.system('pip install colorama')
     os.system('pip install pyAesCrypt')
+    os.system('pip install pyautogui')
 class hack:
     def ttbb():
         import os
@@ -153,6 +154,8 @@ class hack:
     def connect(site):
         import requests
         requests.get("https://"+site)
+        try:
+            print('True')
 class cmd():
     def command():
         print('Для получения сведений об определенной команде наберите HELP <имя команды>')
